/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'iframe', 'ja', {
	border: 'フレームの枠を表示',
	noUrl: 'iframeのURLを入力してください。',
	scrolling: 'スクロールバーの表示を許可',
	title: 'iFrameのプロパティ',
	toolbar: 'IFrame',
	tabindex: 'Remove from tabindex' // MISSING
} );
